@@ -1,22 +1,22 @@
 # -*- coding: latin-1 -*-
-# Copyright (c) 2008-2009 Michael Howitz
+# Copyright (c) 2008-2010 Michael Howitz
 # See also LICENSE.txt
-# $Id: evolve1.py 1121 2009-04-05 20:19:30Z mac $
+# $Id: evolve1.py 783 2010-01-09 14:28:06Z icemac $
 
 __docformat__ = "reStructuredText"
 
 import zope.app.generations.utility
 
 import icemac.addressbook.interfaces
-import icemac.addressbook.addressbook
 import icemac.addressbook.person
-
+import icemac.addressbook.generations.utils
 
 generation = 1
 
 person_created_with_set_site = icemac.addressbook.utils.set_site(
     icemac.addressbook.person.person_created)
 
+
 def evolve(context):
     """Installs the necessary components for address books.
 
@@ -32,10 +32,6 @@ def evolve(context):
     for person in persons:
         person_created_with_set_site(root, person, None)
 
-    # addressbooks
-    addressbooks = zope.app.generations.utility.findObjectsProviding(
-        root, icemac.addressbook.interfaces.IAddressBook)
-    for addressbook in addressbooks:
-        icemac.addressbook.addressbook.create_address_book_infrastructure(
-            addressbook, None)
+    icemac.addressbook.generations.utils.update_address_book_infrastructure(
+        context)
 
