@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
-# Copyright (c) 2009 Michael Howitz
+# Copyright (c) 2009-2010 Michael Howitz
 # See also LICENSE.txt
-# $Id: testing.py 1161 2009-05-01 12:27:31Z mac $
+# $Id: testing.py 826 2010-02-05 17:37:36Z icemac $
 
 import doctest
 import icemac.addressbook.address
@@ -13,6 +13,7 @@ import icemac.addressbook.principals.sources
 import icemac.addressbook.utils
 import os
 import os.path
+import re
 import tempfile
 import unittest
 import zope.annotation.attribute
@@ -20,14 +21,16 @@ import zope.app.testing.functional
 import zope.testbrowser.browser
 import zope.testbrowser.interfaces
 import zope.testing.cleanup
+import zope.testing.renormalizing
 import zope.testing.testrunner.layer
 
+
 class AddressBookUnitTests(zope.testing.testrunner.layer.UnitTests):
     """Layer for gathering addressbook unit tests."""
 
     @classmethod
     def setUp(cls):
-        # some classes use gocept.reference and store default values for
+        # Some classes use gocept.reference and store default values for
         # which annotations are needed.
         zope.component.provideAdapter(
             zope.annotation.attribute.AttributeAnnotations)
@@ -37,9 +40,17 @@ class AddressBookUnitTests(zope.testing.testrunner.layer.UnitTests):
         zope.testing.cleanup.tearDown()
 
 
-def UnittestSuite(class_):
-    """Create a unittest test suite from a unittest test class."""
-    suite = unittest.makeSuite(class_)
+def UnittestSuite(*classes):
+    """Create a unittest test suite from unittest test classes."""
+    suite = unittest.TestSuite()
+    for class_ in classes:
+        suite.addTest(unittest.makeSuite(class_))
+    return suite
+
+
+def AddressBookUnittestSuite(*classes):
+    """Create a unittest test suite on addressbook layer."""
+    suite = UnittestSuite(*classes)
     suite.layer = AddressBookUnitTests
     return suite
 
@@ -60,8 +71,18 @@ def FunctionalDocFileSuite(*paths, **kw):
     kw['optionflags'] = (kw.get('optionflags', 0) |
                          doctest.ELLIPSIS |
                          doctest.NORMALIZE_WHITESPACE)
+    if kw.has_key('layer'):
+        layer = kw.pop('layer')
+    else:
+        layer = FunctionalLayer
+    if not kw.has_key('checker'):
+        kw['checker'] = zope.testing.renormalizing.RENormalizing([
+            (re.compile(r'[0-9]{2}/[0-9]{2}/[0-9]{2} [0-9]{2}:[0-9]{2}'),
+             '<DATETIME>')
+            ])
+
     suite = zope.app.testing.functional.FunctionalDocFileSuite(*paths, **kw)
-    suite.layer = FunctionalLayer
+    suite.layer = layer
     return suite
 
 
@@ -105,7 +126,7 @@ def write_temp_file(content, suffix):
     fd, filename = tempfile.mkstemp(suffix=suffix)
     os.write(fd, content)
     os.close(fd)
-    return file(filename, 'r'), filename
+    return file(filename, 'r'), os.path.basename(filename)
 
 
 def create_addressbook(parent=None, name='ab', title=u'test address book'):
@@ -117,11 +138,12 @@ def create_addressbook(parent=None, name='ab', title=u'test address book'):
     return ab
 
 
-def create_keyword(addressbook, title, notes=u''):
+def create_keyword(addressbook, title, return_obj=True):
     parent = addressbook.keywords
     name = icemac.addressbook.utils.create_and_add(
-        parent, icemac.addressbook.keyword.Keyword, title=title, notes=notes)
-    return parent[name]
+        parent, icemac.addressbook.keyword.Keyword, title=title)
+    if return_obj:
+        return parent[name]
 
 
 @icemac.addressbook.utils.set_site
@@ -178,6 +200,30 @@ def create_phone_number(person, set_as_default=True, return_obj=True, **kw):
         return number
 
 
+@icemac.addressbook.utils.set_site
+def create(
+    parent, entity_name, return_obj=False, set_as_default=False, *args, **kw):
+    """Create an object using an entity.
+
+    entity_name ... module name and class name of entity
+
+    """
+    entity = zope.component.getUtility(
+        icemac.addressbook.interfaces.IEntity, name=entity_name)
+    name = icemac.addressbook.utils.create_and_add(
+        parent, entity.getClass(), *args)
+    obj = parent[name]
+    for key, value in kw.items():
+        field = entity.getField(key)
+        context = field.interface(obj)
+        field.set(context, value)
+    if set_as_default:
+        field = icemac.addressbook.person.get_default_field(entity.interface)
+        field.set(parent, obj)
+    if return_obj:
+        return obj
+
+
 @icemac.addressbook.utils.set_site
 def create_user(ab, first_name, last_name, email, password, roles):
     person = create_person(
@@ -195,3 +241,18 @@ def create_user(ab, first_name, last_name, email, password, roles):
     icemac.addressbook.utils.create_and_add(
         ab.principals, icemac.addressbook.principals.principals.Principal,
         person=person, password=password, roles=selected_roles)
+
+
+@icemac.addressbook.utils.set_site
+def create_field(entity_name, type, title, **kw):
+    """Create a user defined field for an entity.
+
+    entity_name ... module name and class name of entity
+    type ... see values of sources.FieldTypeSource
+
+    """
+    field = icemac.addressbook.utils.create_obj(
+        icemac.addressbook.entities.Field, type=type, title=title, **kw)
+    entity = zope.component.getUtility(
+        icemac.addressbook.interfaces.IEntity, name=entity_name)
+    icemac.addressbook.entities.store_and_register_field(field, entity)
